==> haskell-connection-0.3.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.3.1
id: connection-0.3.1-A3shpGV1MHEHhWhj8UzOMs
key: connection-0.3.1-A3shpGV1MHEHhWhj8UzOMs
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
abi: 452e6f8dbaeca41d7ce9239d196be18b
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/connection-0.3.1
hs-libraries: HSconnection-0.3.1-A3shpGV1MHEHhWhj8UzOMs
depends:
    base-4.12.0.0 basement-0.0.11-C095fEhcIb5E8Z5F95kg3I
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    socks-0.6.1-KCd4hxJWd5BIcnjlofF19c tls-1.4.1-IuG8fJEiE8zXCgQSsSCnA
    x509-1.7.5-C3bTySPvCifVV0W9F9BQx
    x509-store-1.6.7-Abo1l4q0E8FBdSV4znGPtR
    x509-system-1.6.6-6bjZ8ys4D5mIaGyOZ7ULRN
    x509-validation-1.6.11-2OxhGjxlv455xB9sFXmOpJ
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.3.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.3.1
id: connection-0.3.1-CedIS3m3bCRKa8qgGaY23g
key: connection-0.3.1-CedIS3m3bCRKa8qgGaY23g
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
abi: 39dacbb1b7bcee5464823e3c839f8475
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/connection-0.3.1
hs-libraries: HSconnection-0.3.1-CedIS3m3bCRKa8qgGaY23g
depends:
    base-4.12.0.0 basement-0.0.11-C095fEhcIb5E8Z5F95kg3I
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    socks-0.6.1-KCd4hxJWd5BIcnjlofF19c tls-1.4.1-F7h1QZLhSudBJChCO705jc
    x509-1.7.5-962kTaLLCiOJ8ugVz1zcXL
    x509-store-1.6.7-G1Pbm6VmLGd1TA3h9CuSyW
    x509-system-1.6.6-EVqfX9X8Wd76BgReC1v0Eh
    x509-validation-1.6.11-ComRo7bgo9g7SKqJKMPh1l
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
